@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['type_0',['Type',['../a00694.html#a099d97275eaf0055a5870379257496bc',1,'rtl::libreoffice_internal::CharPtrDetector&lt; char *, T &gt;::Type'],['../a00702.html#a42a8350585ca497d33c2d2ccf4addd15',1,'rtl::libreoffice_internal::NonConstCharArrayDetector&lt; char[N], T &gt;::Type'],['../a00710.html#a28efe8c0d1cbf12531ba41c71923392c',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;::Type'],['../a00718.html#a74ff5a7199580150e377a53aecac91e5',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; const sal_Unicode *, T &gt;::Type'],['../a00722.html#aa3d4b27ff0bc4723c1fa792cc8068736',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; sal_Unicode *, T &gt;::Type'],['../a00730.html#ac656c24e3f3cae795b3b993797be1ccb',1,'rtl::libreoffice_internal::Enable&lt; T, true &gt;::Type'],['../a00690.html#abe914ff74f7219275474ec5a791eddc4',1,'rtl::libreoffice_internal::CharPtrDetector&lt; const char *, T &gt;::Type']]],
+  ['type_0',['Type',['../a00690.html#ab5f786d4f146579ea4f0dee29706d118',1,'rtl::libreoffice_internal::CharPtrDetector&lt; const char *, T &gt;::Type'],['../a00694.html#ab37d4a2f49f310faae32e983cb2c66b0',1,'rtl::libreoffice_internal::CharPtrDetector&lt; char *, T &gt;::Type'],['../a00702.html#ada81bc11618c230252403b28b540c946',1,'rtl::libreoffice_internal::NonConstCharArrayDetector&lt; char[N], T &gt;::Type'],['../a00710.html#a93c2f352a7bd00c0e73b84b6e79b177e',1,'rtl::libreoffice_internal::ConstCharArrayDetector&lt; const char[N], T &gt;::Type'],['../a00718.html#a6ec1447582a6a15cf97de5197af8fa46',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; const sal_Unicode *, T &gt;::Type'],['../a00722.html#af506e971b2de71313a9a2c9f96ec1f29',1,'rtl::libreoffice_internal::SalUnicodePtrDetector&lt; sal_Unicode *, T &gt;::Type'],['../a00730.html#a35aa3c09eb3779ed1294ec181f12cec6',1,'rtl::libreoffice_internal::Enable&lt; T, true &gt;::Type']]],
   ['typelib_5fcompoundmember_5finit_1',['typelib_CompoundMember_Init',['../a00251.html#aa5c7b9b7196d0a4ba0a4e22ac94d4dfb',1,'typedescription.h']]],
   ['typelib_5fcompoundtypedescription_2',['typelib_CompoundTypeDescription',['../a00251.html#a35f7c218b18f14a3d745a6bd8ff7cee0',1,'typedescription.h']]],
   ['typelib_5fenumtypedescription_3',['typelib_EnumTypeDescription',['../a00251.html#ad24e07aaa537cbed3e6eaa30c4a971bb',1,'typedescription.h']]],
